"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.startPortal = void 0;
const as_table_1 = __importDefault(require("as-table"));
const lodash_1 = __importDefault(require("lodash"));
const colorette_1 = require("colorette");
const repl = require('node:repl');
const table = as_table_1.default.configure({
    title: (x) => (0, colorette_1.bold)((0, colorette_1.green)(x)),
    delimiter: (0, colorette_1.gray)(' | '),
    dash: (0, colorette_1.gray)('-'),
});
const serialize = (c, serializer) => {
    if (lodash_1.default.isArray(c)) {
        return lodash_1.default.map(c, serializer);
    }
    else {
        return serializer(c);
    }
};
const to = (c) => console.log(table(serialize(c, (v) => v.toJSON())));
const tr = (c) => console.log(table(serialize(c, (v) => v.get())));
const oo = (c) => console.log(serialize(c, (v) => v.toJSON()));
const ro = (c) => console.log(serialize(c, (v) => v.get()));
const startPortal = (context) => {
    const models = context.models();
    const controllers = context.controllers();
    const environment = context.environment();
    const printRoutes = context.helpers.printRoutes;
    const printJobCounts = context.helpers.printJobCounts;
    const replServer = repl.start({
        prompt: `⚡[${(0, colorette_1.bold)((0, colorette_1.green)(environment))}] ${(0, colorette_1.bold)((0, colorette_1.white)('>'))} `,
    });
    Object.assign(replServer.context, models);
    Object.assign(replServer.context, { to, tr, oo, ro });
    replServer.defineCommand('jobs', {
        help: 'show job counts',
        action() {
            return __awaiter(this, void 0, void 0, function* () {
                this.clearBufferedCommand();
                yield printJobCounts(context.workers());
                this.displayPrompt();
            });
        },
    });
    replServer.defineCommand('models', {
        help: 'show models',
        action() {
            this.clearBufferedCommand();
            console.log(`${Object.keys(models).join('\n')}`);
            this.displayPrompt();
        },
    });
    replServer.defineCommand('routes', {
        help: 'show routes',
        action(snippets) {
            this.clearBufferedCommand();
            printRoutes(controllers, snippets ? [snippets] : undefined);
            this.displayPrompt();
        },
    });
    replServer.defineCommand('saybye', function saybye() {
        console.log('Goodbye!');
        // @ts-expect-error 2683
        this.close();
    });
};
exports.startPortal = startPortal;
